# encoding: utf-8

# File:        clients/inst_check_ip.ycp
# Package:     novell-common
# Summary:     Check for static ip and valid host name and dns name
# - warn user of any errors
#
module Yast
  class InstCheckIpClient < Client
    def main

      Yast.import "Service"
      Yast.import "Package"
      Yast.import "Label"
      Yast.import "Stage"
      Yast.import "NovellUtils"
      Yast.import "Report"
      Yast.import "NetworkInterfaces"
      Yast.import "FileUtils"

      textdomain "novell-base"

      @msg = ""
      @hostnameErrorMsg = ""
      @staticIPErrorMsg = ""
      @hostnameError = false
      @staticIPError = false

      @ret = :auto

      @args = Convert.to_map(WFM.Args(0))
      return @ret if Ops.get_boolean(@args, "going_back", false) == true

      if FileUtils.Exists("/var/lib/YaST2/OES11_AUTOUPGRADE")
        Builtins.y2milestone("inst_check_ip: autoyast upgrade mode")
        return @ret
      end
      # Call the NSS evms single volume setup script
      # Fix for Bug 667553
      #string cmd = "/opt/novell/nss/sbin/evms_boot_fix.bsh";
      #y2milestone("inst_check_ip: Executing: %1", cmd);
      #integer rval = (integer)SCR::Execute(.target.bash, cmd);
      #if (rval == 0)
      #	y2milestone("inst_check_ip:execution of '%1' succeeded", cmd);
      #else
      #	y2milestone("inst_check_ip:execution of '%1' did NOT succeed. Err = %2", cmd, rval);


      if Package.Installed("novell-web-base") # FIXME: is this valid???  can we be sure this is the only case we need a static IP??  Why not check based on which service is selected for config in NovellAddonInstall??
        # Check for hostname error
        @host = NovellUtils.GetHostname
        Builtins.y2milestone("inst_check_ip:started host = %1", @host)
        if @host == nil || @host == "" || @host == "linux" ||
            @host == "linux.site"
          @hostnameError = true
          @hostnameErrorMsg = Builtins.sformat(
            _(
              "The host name '%1' is not valid.\nPlease go back and select a valid host name.\n"
            ),
            @host
          )
        end

        @iplist = NovellUtils.GetAllStaticIPAddrs
        if Builtins.size(@iplist) == 0
          @staticIPError = true
          @staticIPErrorMsg = _(
            "This machine does not have an IPv4 static IP address.\n" +
              "Without an IPv4 static IP address eDirectory will not work in an OES environment.\n" +
              "Please go back to the 'Network Configuration' section\n" +
              "to configure an IPv4 static IP address. eDirectory configuration will fail on opting to proceed without an IPv4 static IP address."
          )
        end

        if @hostnameError && @staticIPError
          @msg = Ops.add(
            Ops.add(
              Ops.add(
                Ops.add(
                  Ops.add(@msg, Builtins.sformat("%1)", 1)),
                  @hostnameErrorMsg
                ),
                "\n\n"
              ),
              Builtins.sformat("%1)", 2)
            ),
            @staticIPErrorMsg
          )
        elsif @hostnameError
          @msg = @hostnameErrorMsg
        elsif @staticIPError
          @msg = @staticIPErrorMsg
        end
        if Ops.greater_than(Builtins.size(@msg), 0)
          # if (Report::AnyQuestion(_("Invalid Network Configuration"), sformat("%1\n%2\n\n", msg, _("Do you want to change your Network Configuration?")), Label::YesButton(), Label::NoButton(), `focus_yes)) ret = `net;
          # else ret = `skip;
          if Report.AnyQuestion(
              _("Invalid Network Configuration"),
              Builtins.sformat(
                "%1\n\n%2\n\n",
                @msg,
                _("Do you want to change your Network Configuration?")
              ),
              Label.YesButton,
              Label.NoButton,
              :focus_yes
            )
            @ret = :back
          end
          Builtins.y2milestone("Stage::stage = %1", Stage.stage)
          if @ret == :back && Stage.normal
            @ret = Convert.to_symbol(WFM.CallFunction("lan"))
          end
          if @ret == :back && Stage.stage == "continue"
            @ret = Convert.to_symbol(WFM.CallFunction("lan"))
          end
        end
      end
      @ret = :auto if @ret == nil

      Builtins.y2milestone("inst_check_ip returned: %1", @ret)
      @ret 

      # EOF
    end
  end
end

Yast::InstCheckIpClient.new.main
