# encoding: utf-8

# Copyright (c) 2020 Micro Focus or one of its affiliates.
# File:    clients/inst_autosetup.ycp
# Package: Auto-installation
# Summary: Setup and prepare system for auto-installation
# Authors: Anas Nashif <nashif@suse.de>
#          Uwe Gansert <ug@suse.de>
#
# $Id: inst_autosetup.ycp 61521 2010-03-29 09:10:07Z ug $
module Yast
  class OesAutosetupUpgradeClient < Client
    include Yast::Logger

    def main
      Yast.import "Pkg"
      Yast.import "UI"
      Yast.import "NovellUtils"

      textdomain "autoinst"

      @ret = :auto

      Packages.Init(true)
      if true
        PackageCallbacks.SetConvertDBCallbacks

        Pkg.TargetInit(Installation.destdir, false)

      end

      packages_list=[["novell-cifs","novell-cifs"],
	             ["novell-cluster-services","novell-ncs"],
	             ["novell-oes-dhcp-conf","novell-dhcp"],
	             ["novell-bind","novell-dns"],
	             ["novell-xad-framework","novell-domain-services"],
                     ["novell-NDSimon","novell-edirectory"],
                     ["novell-pure-ftpd-config","novell-ftp"],
                     ["novell-imanager","novell-imanager"],
                     ["novell-iprint-server","novell-iprint"],
                     ["novell-lum","novell-lum"],
                     ["novell-ncp2nss","novell-ncp"],
                     ["novell-premigration-server","novell-premigration-server"],
                     ["novell-nrm","novell-nrm"],
                     ["novell-sms","novell-sms"],
                     ["novell-vigil","novell-nss"],
                     ["novell-iprint-mobile","iprint-advanced"],
                     ["novell-business-continuity-cluster","novell-bcc"],
                     ["novell-nurm","novell-nssad"]]

      Builtins.y2milestone("inst_oes_autosetup_upgrade: Selecting patterns")

      Builtins.foreach(packages_list) do |key,value|
        @package_properties = Pkg.ResolvableProperties(key, :package, "")
        Builtins.foreach(@package_properties) do |p|
          if Ops.get(p, "status") == :selected || Ops.get(p, "status") == :installed || Ops.get(p, "status") == :removed
            Pkg.ResolvableInstall(value, :pattern)
            Builtins.y2milestone("%1 pattern selected",value)
          end
        end
      end

      #Removing OES addon product xml file
      Builtins.y2milestone("Checking OES addonproduct xml during upgrade")
      @cmd = "grep -l  'control-OES' /mnt/etc/YaST2/control_files/*.xml"
      @val1= Convert.to_map(SCR.Execute(path(".target.bash_output"), @cmd))
      exit = Ops.get_integer(@val1, "exit", -1)
      if exit == 0
        filename = NovellUtils.CleanUpString(Ops.get_string(@val1, "stdout", ""))
        @cmd2 = Builtins.sformat("rm -f %1",filename)
        @rval2 = Convert.to_integer(SCR.Execute(path(".target.bash"), @cmd2))
        Builtins.y2milestone(
          "inst_oes_autosetup_upgrade: executing cmd: %1  rval: %2",
          @cmd2,
          @rval2
        )
      end
    @ret
    end
  end
end

Yast::OesAutosetupUpgradeClient.new.main
